#ifndef SCIFIGS_HEADERS
#define SCIFIGS_HEADERS

// All headers of SciFigs library

#include "AbstractLine.h"
#include "AbstractNameLine.h"
#include "ActivityMonitor.h"
#include "AlignGridParameters.h"
#include "AutoAdjustScale.h"
#include "Axis.h"
#include "AxisWindow.h"
#include "Brush.h"
#include "CircleMask.h"
#include "CircleViewer.h"
#include "ColorMapLayer.h"
#include "ColorMapProperties.h"
#include "ColorMapTable.h"
#include "ColorMapWidget.h"
#include "ColorPaletteEditor.h"
#include "ComplexStatisticalLine.h"
#include "ExportOptions.h"
#include "ExternalPlotLine2D.h"
#include "Font.h"
#include "FontScales.h"
#include "GraphContents.h"
#include "GraphContentsLayer.h"
#include "GraphContentsLayerFactory.h"
#include "GraphContentsOptions.h"
#include "GraphicObject.h"
#include "GraphicObjectFactory.h"
#include "GraphicObjectGroup.h"
#include "GraphicObjectList.h"
#include "GraphicSheet.h"
#include "GraphicSheetMenu.h"
#include "GridMaxFollower.h"
#include "GridPlot.h"
#include "GridViewer.h"
#include "HistogramLayer.h"
#include "ImageWidget.h"
#include "IrregularGrid2DPlot.h"
#include "LayerLocker.h"
#include "LayerMouseTracking.h"
#include "LayerPicker.h"
#include "Legend.h"
#include "LegendItem.h"
#include "LegendItemWidget.h"
#include "LegendProperties.h"
#include "LegendTable.h"
#include "LegendTableDelegate.h"
#include "LegendWidget.h"
#include "LineDelegate.h"
#include "LineEditor.h"
#include "LineFactory.h"
#include "LineItem.h"
#include "LineLayer.h"
#include "LineLayerProperties.h"
#include "ListInterpole.h"
#include "LiveCurveLayer.h"
#include "LiveGridLayer.h"
#include "MakeUpFilter.h"
#include "MeshLayer.h"
#include "MouseTracking.h"
#include "NameLine.h"
#include "NameLineDelegate.h"
#include "NameLineItem.h"
#include "NameLineLayer.h"
#include "PageSize.h"
#include "PaintProgress.h"
#include "ParallelBand.h"
#include "ParallelBands.h"
#include "Pen.h"
#include "PlotLine.h"
#include "PlotLine2D.h"
#include "PolarGridPlot.h"
#include "RealStatisticalLine.h"
#include "SciFigsDLLExport.h"
#include "SciFigsGlobal.h"
#include "SciFigsPlugin.h"
#include "SciFigsPreferences.h"
#include "SciFigsXMLEditor.h"
#include "SheetSelectionWidget.h"
#include "SlopeEstimator.h"
#include "Symbol.h"
#include "TextEdit.h"
#include "Ticks.h"
#include "XMLSciFigs.h"
#include "XUniqueYColorLines.h"
#include "XYColorLines.h"
#include "XYColorLinesProperties.h"
#include "XYColorPlot.h"
#include "XYPlot.h"
#include "XYPlotProperties.h"
#include "XYValueLines.h"
#include "XYValuePlot.h"
#include "ui_AlignGridParameters.h"
#include "ui_AutoAdjustScaleProperties.h"
#include "ui_AxisFormatProperties.h"
#include "ui_AxisScaleProperties.h"
#include "ui_ColorMapProperties.h"
#include "ui_ColorPaletteEditor.h"
#include "ui_GraphContentsFormatProperties.h"
#include "ui_GraphContentsLayerProperties.h"
#include "ui_GraphicObjectGeometryProperties.h"
#include "ui_GraphicObjectIdProperties.h"
#include "ui_GraphicObjectPrintProperties.h"
#include "ui_GraphicSheetProperties.h"
#include "ui_GridProperties.h"
#include "ui_ImageWidgetProperties.h"
#include "ui_LegendFormatProperties.h"
#include "ui_LegendProperties.h"
#include "ui_LineLayerProperties.h"
#include "ui_ListInterpole.h"
#include "ui_MakeUpFilter.h"
#include "ui_NameLineLayerProperties.h"
#include "ui_PageSizeProperties.h"
#include "ui_PointProperties.h"
#include "ui_SciFigsPreferences.h"
#include "ui_TextEditProperties.h"
#include "ui_XYColorLinesProperties.h"
#include "ui_XYPlotProperties.h"

#ifndef GP_EXPLICIT_LIBRARY_NAMESPACE
using namespace SciFigs;
#endif

#endif // SCIFIGS_HEADERS
